@@ -16,7 +16,6 @@
 #include "PositionTracking.h"
 #include "MarbleDebug.h"
 #include "MarbleModel.h"
-#include "MarbleMath.h"
 #include "ViewportParams.h"
 #include "MarbleGlobal.h"
 #include "RoutingManager.h"
@@ -135,7 +134,7 @@ GeoDataCoordinates AutoNavigation::Private::findIntersection( qreal currentX, qr
 
     //calculation of intersection point
     if( 0 < direction && direction < 90 ) {
-        const qreal angle = direction;
+        const qreal angle = direction * DEG2RAD;
 
         //Intersection with line x = width
         intercept.setX( width - currentX );
@@ -158,7 +157,7 @@ GeoDataCoordinates AutoNavigation::Private::findIntersection( qreal currentX, qr
 
     }
     else if( 270 < direction && direction < 360 ) {
-        const qreal angle = direction - 270;
+        const qreal angle = (direction - 270) * DEG2RAD;
 
         //Intersection with line y = 0
         intercept.setY( currentY );
@@ -181,7 +180,7 @@ GeoDataCoordinates AutoNavigation::Private::findIntersection( qreal currentX, qr
 
     }
     else if( 180 < direction && direction < 270  ) {
-        const qreal angle = direction - 180;
+        const qreal angle = (direction - 180) * DEG2RAD;
 
         //Intersection with line x = 0
         intercept.setX( currentX );
@@ -204,7 +203,7 @@ GeoDataCoordinates AutoNavigation::Private::findIntersection( qreal currentX, qr
 
     }
     else if( 90 < direction && direction < 180  ) {
-        const qreal angle = direction - 90;
+        const qreal angle = (direction - 90) * DEG2RAD;
 
         //Intersection with line y = height
         intercept.setY( height - currentY );
@@ -236,7 +235,7 @@ GeoDataCoordinates AutoNavigation::Private::findIntersection( qreal currentX, qr
         destinationVertical.setY( currentY );
         crossVertical = true;
     }
-    else if( direction == 190 ) {
+    else if( direction == 180 ) {
         destinationHorizontal.setX( currentX );
         destinationHorizontal.setY( height );
         crossHorizontal = true;
