@@ -14,8 +14,7 @@
 
 #include <QtGlobal>
 
-#include "GeoDataCoordinates.h"
-#include <math.h>
+#include <cmath>
 
 
 namespace
@@ -59,23 +58,6 @@ inline qreal distanceSphere( qreal lon1, qreal lat1, qreal lon2, qreal lat2 ) {
 }
 
 
-/**
- * @brief This method calculates the shortest distance between two points on a sphere.
- * @brief See: http://en.wikipedia.org/wiki/Great-circle_distance
- */
-inline qreal distanceSphere( const GeoDataCoordinates& coords1, const GeoDataCoordinates& coords2 ) {
-
-    qreal lon1, lat1;
-    coords1.geoCoordinates( lon1, lat1 );
-    qreal lon2, lat2;
-    coords2.geoCoordinates( lon2, lat2 );
-
-    // FIXME: Take the altitude into account!
-
-    return distanceSphere( lon1, lat1, lon2, lat2 );
-}
-
-
 /**
  * @brief This method roughly calculates the shortest distance between two points on a sphere.
  * @brief It's probably faster than distanceSphere(...) but for 7 significant digits only has
