@@ -596,31 +596,11 @@ GeoDataLatLonBox GeoDataLatLonBox::toCircumscribedRectangle() const
         }
     }
 
-    box.setBoundaries( GeoDataCoordinates::normalizeLat( box.north() ),
-                       GeoDataCoordinates::normalizeLat( box.south() ),
-                       GeoDataCoordinates::normalizeLon( box.east()  ),
-                       GeoDataCoordinates::normalizeLon( box.west()  )  );
+    box.setBoundaries(box.north(), box.south(), box.east(), box.west());
+
     return box;
 }
 
-QString GeoDataLatLonBox::toString( GeoDataCoordinates::Unit unit ) const
-{
-    switch( unit ){
-    default:
-    case GeoDataCoordinates::Radian:
-        return QString( "North: %1; West: %2; South: %3; East: %4" )
-            .arg( d->m_north ).arg( d->m_west ).arg( d->m_south ).arg( d->m_east );
-        break;
-    case GeoDataCoordinates::Degree:
-        return QString( "North: %1; West: %2; South: %3; East: %4" )
-            .arg( d->m_north * RAD2DEG ).arg( d->m_west * RAD2DEG ).arg( d->m_south * RAD2DEG ).arg( d->m_east * RAD2DEG ); 
-        break;
-    }
-
-    return QString( "GeoDataLatLonBox::text(): Error in unit: %1\n" )
-	.arg( unit );
-}
-
 GeoDataLatLonBox& GeoDataLatLonBox::operator=( const GeoDataLatLonBox &other )
 {
     GeoDataObject::operator=( other );
@@ -833,8 +813,6 @@ bool GeoDataLatLonBox::fuzzyCompare(const GeoDataLatLonBox& lhs,
         if (fabs(lhsEast - rhsEast) > lonDelta) equal = false;
     }
     else {
-        lhsEast = GeoDataCoordinates::normalizeLat( lhsEast );
-        rhsEast = GeoDataCoordinates::normalizeLat( rhsEast );
         if (lhsEast < 0 && rhsEast > 0) {
             lhsEast += 2 * M_PI;
             if (fabs(lhsEast - rhsEast) > lonDelta) equal = false;
@@ -852,8 +830,6 @@ bool GeoDataLatLonBox::fuzzyCompare(const GeoDataLatLonBox& lhs,
        if (fabs(lhsWest - rhsWest) > lonDelta) equal = false;
     }
     else {
-        lhsWest = GeoDataCoordinates::normalizeLat( lhsWest );
-        rhsWest = GeoDataCoordinates::normalizeLat( rhsWest );
         if (lhsWest < 0 && rhsWest > 0) {
             lhsWest += 2 * M_PI;
             if (fabs(lhsWest - rhsWest) > lonDelta) equal = false;
