@@ -22,25 +22,25 @@ class LogfilePlugin : public ParseRunnerPlugin
     Q_INTERFACES( Marble::ParseRunnerPlugin )
 
 public:
-    explicit LogfilePlugin( QObject *parent = 0 );
+    explicit LogfilePlugin( QObject *parent = nullptr );
 
-    QString name() const;
+    QString name() const override;
 
-    QString nameId() const;
+    QString nameId() const override;
 
-    QString version() const;
+    QString version() const override;
 
-    QString description() const;
+    QString description() const override;
 
-    QString copyrightYears() const;
+    QString copyrightYears() const override;
 
     QVector<PluginAuthor> pluginAuthors() const override;
 
-    QString fileFormatDescription() const;
+    QString fileFormatDescription() const override;
 
-    QStringList fileExtensions() const;
+    QStringList fileExtensions() const override;
 
-    virtual ParsingRunner* newRunner() const;
+    ParsingRunner* newRunner() const override;
 };
 
 }
