@@ -5,29 +5,35 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
+// Copyright 2016      Dennis Nienhüser <nienhueser@kde.org>
 // Copyright 2016      David Kolozsvari <freedawson@gmail.com>
 //
 
 #ifndef TINYPLANETPROCESSOR_H
 #define TINYPLANETPROCESSOR_H
 
-#include "BaseFilter.h"
 #include "OsmPlacemarkData.h"
 
 #include <GeoDataLatLonBox.h>
 #include "GeoDataPlacemark.h"
 #include "GeoDataLinearRing.h"
+#include "GeoDataBuilding.h"
+#include "GeoDataMultiGeometry.h"
 #include <TileId.h>
 #include <GeoSceneMercatorTileProjection.h>
 #include <OsmObjectManager.h>
+#include "GeoDataDocument.h"
 
 #include "clipper/clipper.hpp"
+#include <QMap>
+#include <QSet>
 
 namespace Marble {
 
 class GeoDataLinearRing;
+class GeoDataRelation;
 
-class VectorClipper : public BaseFilter
+class VectorClipper
 {
 public:
     VectorClipper(GeoDataDocument* document, int maxZoomLevel);
@@ -37,17 +43,24 @@ public:
 
 private:
     GeoDataDocument* clipTo(const GeoDataLatLonBox &box, int zoomLevel);
-    GeoDataDocument* clipToBaseClipper(const GeoDataLatLonBox &box);
     QVector<GeoDataPlacemark*> potentialIntersections(const GeoDataLatLonBox &box) const;
     ClipperLib::Path clipPath(const GeoDataLatLonBox &box, int zoomLevel) const;
     qreal area(const GeoDataLinearRing &ring);
-    void setBorderPoints(OsmPlacemarkData &osmData, const QVector<int> &borderPoints, int length) const;
     void getBounds(const ClipperLib::Path &path, ClipperLib::cInt &minX, ClipperLib::cInt &maxX, ClipperLib::cInt &minY, ClipperLib::cInt &maxY) const;
 
     template<class T>
-    void clipString(const GeoDataPlacemark *placemark, const ClipperLib::Path &tileBoundary, qreal minArea, GeoDataDocument* document)
+    void clipString(const GeoDataPlacemark *placemark, const ClipperLib::Path &tileBoundary, qreal minArea,
+                    GeoDataDocument* document, QSet<qint64> &osmIds)
     {
-        const T* ring = static_cast<const T*>(placemark->geometry());
+        bool isBuilding = false;
+        T* ring;
+        if (const auto building = geodata_cast<GeoDataBuilding>(placemark->geometry())) {
+            ring = geodata_cast<T>(&building->multiGeometry()->at(0));
+            isBuilding = true;
+        } else {
+            GeoDataPlacemark* copyPlacemark = new GeoDataPlacemark(*placemark);
+            ring = geodata_cast<T>(copyPlacemark->geometry());
+        }
         bool const isClosed = ring->isClosed() && canBeArea(placemark->visualCategory());
         if (isClosed && minArea > 0.0 && area(*static_cast<const GeoDataLinearRing*>(ring)) < minArea) {
             return;
@@ -55,7 +68,7 @@ private:
         auto const & osmData = placemark->osmData();
         using namespace ClipperLib;
         Path subject;
-        foreach(auto const & node, *ring) {
+        for(auto const & node: *ring) {
             subject << IntPoint(&node);
         }
         cInt minX, maxX, minY, maxY;
@@ -73,38 +86,43 @@ private:
         } else {
             OpenPathsFromPolyTree(tree, paths);
         }
-        foreach(const auto &path, paths) {
+        for(const auto &path: paths) {
             GeoDataPlacemark* newPlacemark = new GeoDataPlacemark;
             newPlacemark->setVisible(placemark->isVisible());
             newPlacemark->setVisualCategory(placemark->visualCategory());
             T* newRing = new T;
-            QVector<int> borderPoints;
             int index = 0;
-            foreach(const auto &point, path) {
+            for(const auto &point: path) {
                 GeoDataCoordinates const coordinates = point.coordinates();
                 *newRing << coordinates;
                 auto const originalOsmData = osmData.nodeReference(coordinates);
                 if (originalOsmData.id() > 0) {
                     newPlacemark->osmData().addNodeReference(coordinates, originalOsmData);
                 }
-                if (isClosed && !point.isInside(minX, maxX, minY, maxY)) {
-                    borderPoints << index;
-                }
                 ++index;
             }
 
-            newPlacemark->setGeometry(newRing);
+            if (isBuilding) {
+                const auto building = geodata_cast<GeoDataBuilding>(placemark->geometry());
+                GeoDataBuilding* newBuilding = new GeoDataBuilding(*building);
+                newBuilding->multiGeometry()->clear();
+                newBuilding->multiGeometry()->append(newRing);
+                newPlacemark->setGeometry(newBuilding);
+            } else {
+                newPlacemark->setGeometry(newRing);
+            }
             if (placemark->osmData().id() > 0) {
                 newPlacemark->osmData().addTag(QStringLiteral("mx:oid"), QString::number(placemark->osmData().id()));
             }
             copyTags(*placemark, *newPlacemark);
-            setBorderPoints(newPlacemark->osmData(), borderPoints, newRing->size());
             OsmObjectManager::initializeOsmData(newPlacemark);
             document->append(newPlacemark);
+            osmIds << placemark->osmData().id();
         }
     }
 
-    void clipPolygon(const GeoDataPlacemark *placemark, const ClipperLib::Path &tileBoundary, qreal minArea, GeoDataDocument* document);
+    void clipPolygon(const GeoDataPlacemark *placemark, const ClipperLib::Path &tileBoundary, qreal minArea,
+                     GeoDataDocument* document, QSet<qint64> &osmIds);
 
     void copyTags(const GeoDataPlacemark &source, GeoDataPlacemark &target) const;
     void copyTags(const OsmPlacemarkData &originalPlacemarkData, OsmPlacemarkData& targetOsmData) const;
@@ -113,6 +131,7 @@ private:
     int m_maxZoomLevel;
     GeoSceneMercatorTileProjection m_tileProjection;
     QHash<const GeoDataLinearRing*, qreal> m_areas;
+    QSet<GeoDataRelation*> m_relations;
 };
 
 }
